import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;
import com.jinsight.jetchart.*;

/**
 * This demo displays  an  ohlc  series  at  the upper area and an area  series at the lower area. 
 * The ohlc series  displays  a  sequence  of stock  prices over a period of  9 months, while  the
 * lower series displays the volume.
 *
 * Labels and values come from  a database, in  this  case, a MySql(www.mysql.com) database.  Take 
 * a look at the GenericGraph.setLabelsQuery() and AbstractSerie.setValuesQuery() methods to learn 
 * how to fetch labels and series values from a database.
 * OHLC series display data points  directly related  to the open, high, low and close data.  The
 * OHLCSerie class overrides the AbstractSerie.setValuesQuery() method to parse those values.
 */
public class Main extends JFrame   {

    Graph graph;
    
    GraphSerie gs;

    public Main() {
	
	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });

	
	// Creates the chart context and sets several properties.
	createGraph();
	
	// Creates two series, an ohlc series with stock prices and an area series with volume prices.
	createLowerSeries();
	createUpperSeries();

        Container ct=getContentPane();
        
	ct.add(BorderLayout.CENTER,graph);
	
	setSize(700,500);
	
	setVisible(true);

    }

    private void createGraph() {

	graph=new Graph();

	
	// Sets the properties of the primary GraphSet object.
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGrid().setColoredBandsEnabled(true);
	graph.getGraphSet(0).getScale().setEndPoint(0.5F);
	graph.getGraphSet(0).getScale().setValueFormat("#,###,##0.00");

	// Enables the grid crossed lines. First gets a reference to the GridCrossedLines object and then
	// sets its properties.
	graph.getGraphSet(0).getGridCrossedLines().setEnabled(true);
	graph.getGraphSet(0).getGridCrossedLines().setColor(Color.lightGray);


	// Creates a secondary GraphSet object to display the area series and sets its properties.
	GraphSet graphSet=new GraphSet();
	graphSet.getScale().setPosition(Scale.RIGHT);
	graphSet.getScale().setStartPoint(.6F);
	graphSet.getScale().setValueFormat("#,###,##0.00");

	graphSet.getGrid().setEnabled(true);
	graphSet.getGrid().setColor(Color.lightGray);
	graphSet.getScrollingBar().setEnabled(true);
	graphSet.getWall().setEnabled(true);
	graph.addGraphSet(graphSet);
	
	// Sets the database driver  and connection  parameters. This  demo access  a database  named
	// 'ohlc' and a table named 'ohlctable' to fetch labels and series values. See the README.TXT
	// file located at this demo directory. There are  instructions  concerning  a database/table
	// creation.
	graph.setDriver("org.gjt.mm.mysql.Driver");
	graph.setConnection("jdbc:mysql://localhost:3306/ohlc","root","ptax7mf3");

	// Sets the  query  to  fetch labels  from the database/table above mentioned. The result set
	// must return only one column, otherwise an exception is raised.
	graph.setLabelsQuery("SELECT date FROM ohlctable");

	graph.setTitle(new String[]{"The JetChart Library - a financial chart","Database binding example"});

	// Sets the chart background
	graph.setBackground(Color.decode("#649a9c"));

	// Sets a string pattern to format tooltip values.
	graph.setValueFormat("#,###,##0.00");

	// Sets Legend properties
	graph.getLegend().setOpacityEnabled(false);

	// Sets tooltips properties.
	setToolTipProperties();

	// Sets scrolling label properties.
	setScrollingLabelProperties();

	// Displays a scrolling bar across the primary GraphSet area while moving mouse.
	graph.getGraphSet(0).getScrollingBar().setEnabled(true);

	// Displays a wall behind the primary GraphSet area.
	graph.getGraphSet(0).getWall().setEnabled(true);

	// Sets the wall color
	graph.getGraphSet(0).getWall().setColor(new Color(230,230,230));
	
    }
    
    private void setScrollingLabelProperties() {
	
	// Enables  a scrolling label. First gets a reference to the ScrollingLabel object.
	ScrollingLabel sl=graph.getScrollingLabel();
	sl.setEnabled(true);
	// Sets scrolling label description.
	sl.setDescription("Date:");

	// Sets scrolling label color.
	sl.setColor(Color.blue);

    }

    private void setToolTipProperties() {

	// Enables tooltip.
	graph.getToolTip().setEnabled(true);
	
	// Enables multiple tooltips.
	graph.getToolTip().setMultipleEnabled(true);

	// A new method. Sets the tooltip border color to be the same of its respective series.
	// The series are then identified by its tooltip border color. 
	// The matching border is displayed only if the pointer type is set to NONE.
	graph.getToolTip().setMatchingBorderEnabled(true);
	graph.getToolTip().setPointerType(ToolTip.NONE);

	// Sets tooltips background and font.
	graph.getToolTip().setBackground(Color.white);
    }

    private void createLowerSeries() {
	
	// Creates an area series and sets its values query. The result set must contain only one
	// column, otherwise an exception is raised.
	AreaSerie as=new AreaSerie();
	as.setValuesQuery("SELECT volume FROM ohlctable");
	as.setAreaLinesEnabled(false);
	as.setColor(Color.red);

	as.setTitle("Volume");
	graph.addSerie(as);
	graph.getGraphSet(1).addSerie(as);
    }

    private void createUpperSeries() {

	// Creates an ohlc line series and sets its values query.
	OHLCLineSerie os=new OHLCLineSerie();
	os.setValuesQuery("SELECT open,high,low,close FROM ohlctable");

	os.setThickness(2);
	os.setMarksEnabled(false);
       
	os.setTitle("Stock prices");
	os.setColor(Color.green.darker());
	graph.addSerie(os);
	
    }
    
  
    
    public static void main(String[] args) {
	Main m=new Main();
    }

}

