import com.jinsight.jetchart.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import java.util.Vector;
import java.util.EventListener;

/**
 * This  example  demonstrates  handling   of   mouse  clicks.
 * Double click  a series data point and a window pops up  listing
 * related data. Double  click   each   legend   icon   and  watch
 * result. After displaying a pop up window,  click the chart area
 * to dispose of it.
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ItemListener,ChangeListener {

    Graph lineGraph,barGraph,areaGraph,stackBarGraph,pointGraph,imageGraph,comboGraph;
    PieGraph pieGraph;
    GenericGraph activeGraph;

    JTabbedPane jt;
    JCheckBox horizontal,_3D;

    Vector windows=new Vector();
    boolean showNewWindow;

    String[] labels={"label1","label2","label3","label4","label5","label6"};
    
    double[] values={354.23F,453.12F,200.87F,145.93F,231.55F,121.33F};
    double[] values2={244.33F,545.92F,354.12F,254F,419.81F,890.43F};

    Image img1=getToolkit().getImage("image1.gif");
    Image img2=getToolkit().getImage("image2.gif");
    Image img3=getToolkit().getImage("image3.gif");
    Image img4=getToolkit().getImage("image4.gif");
    Image img5=getToolkit().getImage("image5.gif");
    Image img6=getToolkit().getImage("image6.gif");

    Image[] images={img1,img2,img3,img4,img5,img6};	
    

    // The elementsLists1 and elementsList2 arrays keep the lists that will be displayed if 
    // an element of a series is clicked.
    String[][] elementsLists1=new String[][]{{"car","motorcycle","bicycle","airplane"},
				 {"computer","mouse","keyboard","notebook","monitor"},
				 {"apple","orange","watermelon","strawberry","cashew"},
				 {"Andre","Simone","Ivan","Ronaldo","Maria","Valquiria","Carlos"},
				 {"cat","dog","bird","lion","elephant","mouse","tiger","cow","dinosaur"},
				 {"house","kitchen","bedroom","bathroom","dinner-room","carpet","chair"}};
    
    String[][] elementsLists2=new String[][]{{"oven","refrigerator","freezer","mixer"},
				 {"yellow","red","black","orange","blue"},
					     {"pen","pencil","eraser","ruler"},
				 {"iron","silver","gold","diamond","emerald"},
				 {"pants","shirt","dress","socks","brush","shoes"},
				 {"eyes","mouth","hair","hands","legs","foot","fingers"}};

    String[][] elementsLists3=new String[][]{{"U.S.A.","Brasil","India","Portugal"},
				 {"Russia","France","Ireland","Holland","China"},
				 {"Japan","Korea","Malasia","Sweden"},
				 {"South America","North America","Europe","Asia","Africa"},
				 {"Angola","Mocambique","Marrocos","Congo","Africa do Sul","Quenia"},
				 {"Iran","Israel","Siria","Libano","Iraque","Palestina","Turquia"}};
    
    // The seriesLists  array keeps two lists, which will be displayed if a click over 
    // a legend icon is performed.
    String[][] seriesLists=new  String[][]{{"JAVA","PASCAL","COBOL","FORTRAN","SMALLTALK"},
					  {"FOOTBALL","BASKETBALL","VOLEYBALL","HANDBALL"},
                                          {"ENGINEER","DOCTOR","PROGRAMMER","PHYSICIAN"}};
    
    public Main() {

	setTitle("The JetChart Library - Series event demo");
		
        addWindowListener(new WindowAdapter() {
           public void windowClosing(WindowEvent ev) {
              System.exit(0);
           }
        });

	jt=new JTabbedPane();
	jt.addChangeListener(this);

	createLineChart();
	createBarChart();
	createAreaChart();
	createStackBarChart();
	createPointChart();
	createImageChart();
	createPieChart();
	createComboChart();
	
	SerieHandler sh=new SerieHandler();
	
	lineGraph.addSerieListener(sh);

	barGraph.addSerieListener(sh);
	areaGraph.addSerieListener(sh);
	stackBarGraph.addSerieListener(sh);
	pointGraph.addSerieListener(sh);
	imageGraph.addSerieListener(sh);
	pieGraph.addSerieListener(sh);
	comboGraph.addSerieListener(sh);
	
	createBottomPanel();

	getContentPane().add(jt,BorderLayout.CENTER);

        setSize(500,500);
        setVisible(true);

    }

    private void createLineChart() {
	lineGraph=new Graph();

	lineGraph.addMouseListener(new Adapter());
	lineGraph.addMouseMotionListener(new MotionAdapter());

	lineGraph.setTitle(new String[]{"A Line Chart" });
	lineGraph.setDraggingEnabled(true);
	lineGraph.setLabels(labels);
	lineGraph.setGradientColors(Color.white,new Color(180,255,255));
	lineGraph.getGraphSet(0).getGrid().setEnabled(true);
	lineGraph.getGraphSet(0).getGridCrossedLines().setEnabled(true);
	lineGraph.setLabelsAxisStartGap(0);

	LineSerie ls=new LineSerie(values,"Line Series");
	ls.setColor(Color.red);
	ls.setThickness(3);
	lineGraph.addSerie(ls);


	jt.addTab("Line Chart",lineGraph);

    }

    private void createBarChart() {
	barGraph=new Graph();

	barGraph.addMouseListener(new Adapter());
	barGraph.addMouseMotionListener(new MotionAdapter());

	barGraph.setTitle(new String[]{"A Bar Chart" });
	barGraph.setLabels(labels);
	barGraph.getGraphSet(0).getGrid().setEnabled(true);
	BarSerie bs=new BarSerie(values,"Bar Series");
	bs.setColor(Color.green);
	bs.setWidth(20);
	barGraph.addSerie(bs);

	jt.addTab("Bar Chart",barGraph);	

    }

    private void createAreaChart() {
	areaGraph=new Graph();
	
	areaGraph.addMouseListener(new Adapter());
	areaGraph.addMouseMotionListener(new MotionAdapter());

	areaGraph.setTitle(new String[]{"An Area Chart" });
	areaGraph.setGradientColors(Color.white,new Color(051,204,255));
	areaGraph.setGradientOrientation(Graph.LEFT_TO_RIGHT);

	areaGraph.getGraphSet(0).getGrid().setEnabled(true);
	areaGraph.setLabels(labels);
	areaGraph.setLabelsAxisStartGap(0);
	AreaSerie as=new AreaSerie(values,"Area Series");
	as.setColor(Color.yellow);
	areaGraph.addSerie(as);

	jt.addTab("Area Chart",areaGraph);	

    }

    private void createStackBarChart() {

	stackBarGraph=new Graph();

	stackBarGraph.addMouseListener(new Adapter());
	stackBarGraph.addMouseMotionListener(new MotionAdapter());

	stackBarGraph.setTitle(new String[]{"A Stacked Bars Chart" });

	stackBarGraph.getGraphSet(0).getGrid().setEnabled(true);
	stackBarGraph.setLabels(labels);

	StackBarSerie sb1=new StackBarSerie(values,"Stacked Bar Series 1");
	sb1.setColor(Color.cyan);
	sb1.setId(0);

	StackBarSerie sb2=new StackBarSerie(values2,"StackBar Series 2");
	sb2.setColor(Color.orange);
	sb2.setId(1);

	stackBarGraph.addSerie(sb1);
	stackBarGraph.addSerie(sb2);

	
	jt.addTab("Stacked Bar Chart",stackBarGraph);
	
    }
    
    private void createPointChart() {
	pointGraph=new Graph();

	pointGraph.addMouseListener(new Adapter());
	pointGraph.addMouseMotionListener(new MotionAdapter());

	pointGraph.setTitle(new String[]{"A Point Chart" });
	pointGraph.setGradientColors(new Color(051,204,255),Color.yellow);
	pointGraph.getGraphSet(0).getGrid().setEnabled(true);
	pointGraph.setLabels(labels);

	PointSerie ps1=new PointSerie(values,"Point Series 1");
	ps1.setColor(Color.green.darker());
	ps1.setShape(PointSerie.TRIANGLE);
	ps1.setId(0);

	PointSerie ps2=new PointSerie(values2,"Point Series 2");
	ps2.setColor(Color.pink);
	ps2.setId(1);

	pointGraph.addSerie(ps1);
	pointGraph.addSerie(ps2);

	jt.addTab("Point Chart",pointGraph);
	    
    }    

    private void createImageChart() {
	imageGraph=new Graph();

	imageGraph.addMouseListener(new Adapter());
	imageGraph.addMouseMotionListener(new MotionAdapter());

	imageGraph.setTitle(new String[]{"An Image Chart" });

	imageGraph.getGraphSet(0).getGrid().setEnabled(true);
	imageGraph.getToolTip().setEnabled(true);
	imageGraph.setLabels(labels);
	ImageSerie is=new ImageSerie(values,images);
	
	imageGraph.addSerie(is);

	jt.addTab("Image Chart",imageGraph);
	    
    }    


    private void createPieChart() {

	pieGraph=new PieGraph();
	
	pieGraph.addMouseListener(new Adapter());
	pieGraph.addMouseMotionListener(new MotionAdapter());

	pieGraph.setTitle(new String[]{"A Pie Chart" });

	PieSerie ps=new PieSerie();
	Color[] colors={Color.yellow,Color.red,Color.blue,Color.green,Color.cyan,Color.lightGray};
	pieGraph.addSerie(ps);

        // Creates slices and adds them to the pie series.
        for (int counter=0;counter<values.length;counter++) {
           Slice slice=new Slice();
           slice.setValue(values[counter]);
           slice.setTitle(labels[counter]);
           slice.setColor(colors[counter]);
           ps.addSlice(slice);
        }

	ps.setBorderEnabled(true);
	
	jt.addTab("Pie Chart",pieGraph);

    } 

    private void createComboChart() {

	comboGraph=new Graph();

	comboGraph.addMouseListener(new Adapter());
	comboGraph.addMouseMotionListener(new MotionAdapter());

	comboGraph.setTitle(new String[]{"A Combined Chart" });

	comboGraph.setLabels(labels);
	comboGraph.getGraphSet(0).getGrid().setEnabled(true);
	comboGraph.set3DSeriesInLineEnabled(false);
	comboGraph.getLegend().setAutoOrientationEnabled(false);
	comboGraph.getLegend().setPosition(Legend.BOTTOM);
	comboGraph.getGraphSet(0).getXAxis().set3DColor(new Color(134,204,255));
	comboGraph.getGraphSet(0).getYAxis().set3DColor(new Color(134,204,255));

	StackBarSerie sb1=new StackBarSerie(values2,"Stacked Bar Series 1");
	sb1.setColor(Color.pink);
	sb1.setId(0);

	StackBarSerie sb2=new StackBarSerie(values2,"Stacked Bar Series 2");
	sb2.setColor(Color.orange);
	sb2.setId(1);

	BarSerie bs=new BarSerie(values,"Bar Series");
	bs.setColor(Color.yellow);
	bs.setId(2);
	
	comboGraph.addSerie(sb1);
	comboGraph.addSerie(sb2);
	comboGraph.addSerie(bs);

	jt.addTab("Combo Chart",comboGraph);
	
    }
    
	
    
    private void createBottomPanel() {
	JPanel bottomPanel=new JPanel();

	horizontal=new JCheckBox("Horizontal Chart");
	horizontal.addItemListener(this);

	_3D=new JCheckBox("3D");
	_3D.addItemListener(this);

	bottomPanel.add(horizontal);
	bottomPanel.add(_3D);

	getContentPane().add("South",bottomPanel);
    }
	
    public void stateChanged(ChangeEvent evt) {
	Component c=jt.getComponentAt(jt.getSelectedIndex());
	activeGraph=(GenericGraph)c;
    }

	

    public void itemStateChanged(ItemEvent evt) {
	if (evt.getSource()==horizontal) { 
	    lineGraph.setHorizontalGraphEnabled(horizontal.isSelected());
	    barGraph.setHorizontalGraphEnabled(horizontal.isSelected());
	    areaGraph.setHorizontalGraphEnabled(horizontal.isSelected());
	    stackBarGraph.setHorizontalGraphEnabled(horizontal.isSelected());
	    pointGraph.setHorizontalGraphEnabled(horizontal.isSelected());
	    imageGraph.setHorizontalGraphEnabled(horizontal.isSelected());
	    comboGraph.setHorizontalGraphEnabled(horizontal.isSelected());
	}
	if (evt.getSource()==_3D) {
	    lineGraph.set3DEnabled(_3D.isSelected());
	    barGraph.set3DEnabled(_3D.isSelected());
	    areaGraph.set3DEnabled(_3D.isSelected());
	    stackBarGraph.set3DEnabled(_3D.isSelected());
	    pointGraph.set3DEnabled(_3D.isSelected());
	    imageGraph.set3DEnabled(_3D.isSelected());
	    pieGraph.set3DEnabled(_3D.isSelected());
	    comboGraph.set3DEnabled(_3D.isSelected());
	    
	}

	repaintAll();
	
    }	    
    
    private void repaintAll() {
	lineGraph.repaint();
	barGraph.repaint();
	areaGraph.repaint();
	stackBarGraph.repaint();
	pointGraph.repaint();
	imageGraph.repaint();
	pieGraph.repaint();
	comboGraph.repaint();
    }

    class SerieHandler extends SerieAdapter {
	
	public void serieClicked(SerieEvent evt) {

	    String[] obj=null;

	    GenericGraph graph=evt.getGraph();

	    AbstractSerie as=evt.getSerie();
	    
	    if (graph==lineGraph || graph==barGraph || graph==areaGraph || graph==imageGraph) {

		if (evt.getClickCount()==2 && !evt.isOverLegend()) {
		    
		    // gets the index of the element clicked. Ranges from 0 to (the total number of
		    // values of the serie)-1.  
		    int elementIndex=evt.getElementIndex();
		    
		    // gets the list from the elementsLists array
		    // created in the init() method.
		    obj=elementsLists1[elementIndex];
		
		}
		// one click on a legend icon dispatches a series event.
		else if (evt.getClickCount()==1 && evt.isOverLegend())
		    obj=seriesLists[0];
	    }
	    else if (graph==stackBarGraph || graph==pointGraph || graph==comboGraph) {

		if (evt.getClickCount()==2 && !evt.isOverLegend()) {
		    if (as.getId()==0)
			obj=elementsLists1[evt.getElementIndex()];
		    else if (as.getId()==1)
			    obj=elementsLists2[evt.getElementIndex()];
		    else if (as.getId()==2)
			obj=elementsLists3[evt.getElementIndex()];
		    
		}
		// one click on legend icon dispatches a series event.
		else if (evt.getClickCount()==1 && evt.isOverLegend()) 
			obj=seriesLists[as.getId()];

	    }
	    else if (graph==pieGraph) {
		if ((evt.getClickCount()==2 && !evt.isOverLegend()) || (evt.getClickCount()==1 && 
									evt.isOverLegend())) {
		    int elementIndex=evt.getElementIndex();
		    obj=elementsLists1[elementIndex];
		}
		
	    }
		
	    if (obj!=null) {

		PopUpWindow popUp=new PopUpWindow(obj,120,100);
		
		
		// Sets the position where the window will be displayed. It is displayed with its
		// left upper corner positioned at the exact place the mouse was clicked.
		Point p=getLocation();
		SwingUtilities.convertPointToScreen(p,lineGraph);
		
		popUp.setLocation(p.x+evt.getX(),p.y+evt.getY());
		
		popUp.setVisible(true);
		
		// Registers that a new window was created, to control window disposal in the
		// mouseReleased handler of the CustGraph class.
		showNewWindow=true;
		
		// the windows Vector is checked in the series event handler in order to dispose
		// of all visible windows.
		windows.addElement(popUp);

	    }
	    

	}
	
    }

    // A customized JWindow class to display lists.
    class PopUpWindow extends JWindow {

	public PopUpWindow(String[] obj,int width,int height) { 
	    
	    // creates a JList to display the list
	    JList list=new JList();
	    list.setListData(obj);
	    
	    // Creates a JPanel with a border around.
	    JPanel panel=new JPanel();
	    panel.setLayout(new BorderLayout());
	    panel.setBorder(BorderFactory.createTitledBorder("Title"));
	    
	    // Adds the list to the JPanel
	    panel.add(new JScrollPane(list),BorderLayout.CENTER);
	    
	    // Adds the JPanel to the Window
	    this.getContentPane().add(panel,BorderLayout.CENTER);
	    
	    // Sets window size. 
	    setSize(width,height);
	}
    }

    class Adapter extends MouseAdapter {
	
	public void mouseReleased(MouseEvent evt) {
	    
	    // If a single click is performed and a window has been recently displayed, traverses 
	    // the windows Vector in order to dispose of window.
	    if (evt.getClickCount()==1 && showNewWindow) {
		for (int counter=0;counter<windows.size();counter++) {
		    Window w=(Window)windows.elementAt(counter);
		    w.dispose();
		    
		}
		windows.removeAllElements();
	    }
	    // resets window controller.
	    showNewWindow=false;
	    
	}

    }

    class MotionAdapter extends MouseMotionAdapter {
	
	public void mouseDragged(MouseEvent evt) {
	    
	    // If a window has been recently displayed, traverses 
	    // the windows Vector in order to dispose of window.
	    if (showNewWindow) {
		for (int counter=0;counter<windows.size();counter++) {
		    Window w=(Window)windows.elementAt(counter);
		    w.dispose();
		    
		}
		windows.removeAllElements();
		// resets window controller.
		showNewWindow=false;
	    }
	}

    }

    public static void main(String[] args) {
	new Main();		
    }
}
	
